pub(crate) struct SameFormattingContextBlockLayoutResultAndInputs {
pub result: SameFormattingContextBlockLayoutResult,
pub containing_block_size: ContainingBlockSize,
pub containing_block_writing_mode: WritingMode,
pub containing_block_justify_items: AlignFlags,
collapsible_with_parent_start_margin: Option<CollapsibleWithParentStartMargin>,
ignore_block_margins_for_stretch: LogicalSides1D<bool>,
has_inline_parent: bool,
}Expand description
A collection of layout inputs and a cached layout result for a SameFormattingContextBlock for
use in LayoutBoxBase.
Fields
result: SameFormattingContextBlockLayoutResultcontaining_block_size: ContainingBlockSizeThe ContainingBlockSize used when this block was laid out.
containing_block_writing_mode: WritingModeThe containing block’s WritingMode used when this block was laid out.
containing_block_justify_items: AlignFlagsThe containing block’s justify-items AlignFlags used when this block was laid out.
collapsible_with_parent_start_margin: Option<CollapsibleWithParentStartMargin>Whether or not the margin in this block was collapsible with the parent’s start margin when this block was laid out.
ignore_block_margins_for_stretch: LogicalSides1D<bool>Whether or not block margins were ignored for stretch when this block was laid out.
has_inline_parent: boolWhether or not this block had an inline parent.